@@ -458,7 +458,7 @@ class Node(BaseModel):
                 enum_lst = [
                     {k: v} for k, v in input.dict().items() if isinstance(v, Enum)
                 ]
-                print(f"{enum_lst=}")
+                # print(f"{enum_lst=}")
                 for e_pair in enum_lst:
                     for k, v in e_pair.items():
                         variables_val[i][k] = "<REP>" + variables_val[i][k] + "<REP>"
