@@ -215,9 +215,6 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def _get_via_query(self, kwargs_d: dict) -> T.Optional[NodeType]:
         s = self.make_get_query_str_via_query(kwargs_d=kwargs_d)  # TODO change
-        from devtools import debug
-
-        debug(s)
         res = await self.node.GQL.dgraph_client.execute(query_str=s)
 
         obj = res["data"][self.query_query_name()]
